SolidAuthLocalizations class abstract

Callers can lookup localized strings with an instance of SolidAuthLocalizations returned by SolidAuthLocalizations.of(context).

Applications need to include SolidAuthLocalizations.delegate() in their app's localizationDelegates list, and the locales they support in the app's supportedLocales list. For example:

import 'l10n/solid_auth_localizations.dart';

return MaterialApp(
  localizationsDelegates: SolidAuthLocalizations.localizationsDelegates,
  supportedLocales: SolidAuthLocalizations.supportedLocales,
  home: MyApplicationHome(),
);

Update pubspec.yaml

Please make sure to update your pubspec.yaml to include the following packages:

dependencies:
  # Internationalization support.
  flutter_localizations:
    sdk: flutter
  intl: any # Use the pinned version from flutter_localizations

  # Rest of dependencies

iOS Applications

iOS applications define key application metadata, including supported locales, in an Info.plist file that is built into the application bundle. To configure the locales supported by your app, you’ll need to edit this file.

First, open your project’s ios/Runner.xcworkspace Xcode workspace file. Then, in the Project Navigator, open the Info.plist file under the Runner project’s Runner folder.

Next, select the Information Property List item, select Add Item from the Editor menu, then select Localizations from the pop-up menu.

Select and expand the newly-created Localizations item then, for each locale your application supports, add a new item and select the locale you wish to add from the pop-up menu in the Value field. This list should be consistent with the languages listed in the SolidAuthLocalizations.supportedLocales property.

Implementers

Constructors

SolidAuthLocalizations(String locale)

Properties

chooseProvider String
Label for the provider selection section
no setter
connect String
Button text to initiate connection
no setter
connectToSolid String
Title for the Solid login screen
no setter
getPod String
Button text to get a new Pod
no setter
hashCode int
The hash code for this object.
no setterinherited
localeName String
final
noPod String
Text asking if user doesn't have a Pod
no setter
orEnterManually String
Label for manual WebID input section
no setter
pleaseEnterWebId String
Validation message when WebID field is empty
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syncAcrossDevices String
Subtitle explaining the purpose of connecting to Solid
no setter
webIdHint String
Placeholder text for WebID input field
no setter

Methods

errorConnectingSolid(String error) String
Error message when connection fails
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) SolidAuthLocalizations?

Constants

delegate → const LocalizationsDelegate<SolidAuthLocalizations>
localizationsDelegates → const List<LocalizationsDelegate>
A list of this localizations delegate along with the default localizations delegates.
supportedLocales → const List<Locale>
A list of this localizations delegate's supported locales.