SolidAuthLocalizationsEn class

The translations for English (en).

Inheritance

Constructors

SolidAuthLocalizationsEn([String locale = 'en'])

Properties

chooseProvider String
Label for the provider selection section
no setteroverride
connect String
Button text to initiate connection
no setteroverride
connectToSolid String
Title for the Solid login screen
no setteroverride
getPod String
Button text to get a new Pod
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
localeName String
finalinherited
noPod String
Text asking if user doesn't have a Pod
no setteroverride
orEnterManually String
Label for manual WebID input section
no setteroverride
pleaseEnterWebId String
Validation message when WebID field is empty
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syncAcrossDevices String
Subtitle explaining the purpose of connecting to Solid
no setteroverride
webIdHint String
Placeholder text for WebID input field
no setteroverride

Methods

errorConnectingSolid(String error) String
Error message when connection fails
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited